@@ -65,7 +65,7 @@ call_block = function(block) {
     if (params$engine == 'R' && isFALSE(params$cache.comments)) {
       content[['code']] = parse_only(content[['code']])
     }
-    hash = paste(valid_path(params$cache.path, label), digest::digest(content), sep = '_')
+    hash = paste(valid_path(params$cache.path, label), digest(content), sep = '_')
     params$hash = hash
     if (cache$exists(hash, params$cache.lazy) &&
         isFALSE(params$cache.rebuild) &&
