@@ -15,7 +15,7 @@ auto_exts = c(
 
   svglite = 'svg',
 
-  tikz = 'tikz'
+  tikz = 'tex'
 )
 
 dev2ext = function(x) {
@@ -139,14 +139,7 @@ plot2dev = function(plot, name, dev, device, path, width, height, options) {
     # add old wd to TEXINPUTS (see #188)
     oti = Sys.getenv('TEXINPUTS'); on.exit(Sys.setenv(TEXINPUTS = oti))
     Sys.setenv(TEXINPUTS = paste(owd, oti, sep = .Platform$path.sep))
-    latex = switch(
-      getOption('tikzDefaultEngine'),
-      pdftex = getOption('tikzLatex'),
-      xetex  = getOption('tikzXelatex'),
-      luatex = getOption('tikzLualatex'),
-      stop2('a LaTeX engine must be specified for tikzDevice')
-    )
-    system2(latex, shQuote(basename(path)), stdout = NULL)
+    tinytex::latexmk(basename(path), getOption('tikzDefaultEngine'), emulation = TRUE)
     setwd(owd)
     if (!file.exists(pdf.plot)) {
       if (file.exists(log <- paste(name, 'log', sep = '.')))
@@ -260,7 +253,7 @@ remove_plot = function(list, keep.high = TRUE) {
 # replace the content of the recorded plot with MD5 digests so that merge_plot()
 # will still work, and this will also save disk space for the case of cache=2
 digest_plot = function(x, level = 1) {
-  if (!is.list(x) || level >= 3) return(digest::digest(x))
+  if (!is.list(x) || level >= 3) return(digest(x))
   lapply(x, digest_plot, level = level + 1)
 }
 
@@ -288,9 +281,9 @@ fig_process = function(FUN, path) {
 #' The utility \command{pdfcrop} is often shipped with a LaTeX distribution, and
 #' \command{convert} is a command in ImageMagick (Windows users may have to put
 #' the bin path of ImageMagick into the \var{PATH} variable).
-#' @param x the plot filename
-#' @param quiet whether to suppress standard output from the command line
-#'   utility
+#' @param x Filename of the plot.
+#' @param quiet Boolean; whether to suppress standard output from the command line
+#'   utility.
 #' @export
 #' @references PDFCrop: \url{https://www.ctan.org/pkg/pdfcrop}; the
 #'   \command{convert} command in ImageMagick:
@@ -321,10 +314,7 @@ plot_crop = function(x, quiet = TRUE) {
   x
 }
 
-# a wrapper of showtext::showtext.begin()
-showtext = function(show) {
-  if (isTRUE(show)) getFromNamespace('showtext_begin', 'showtext')()
-}
+showtext = function(show) if (isTRUE(show)) showtext::showtext_begin()
 
 # handle some special cases of par()
 par2 = function(x) {
@@ -359,16 +349,16 @@ par2 = function(x) {
 #' Markdown syntax, to embed an external image. Chunk options related to
 #' graphics output that work for normal R plots also work for these images, such
 #' as \code{out.width} and \code{out.height}.
-#' @param path a character vector of image paths
-#' @param auto_pdf whether to use PDF images automatically when the output
-#'   format is LaTeX, e.g. \file{foo/bar.png} will be replaced by
-#'   \file{foo/bar.pdf} if the latter exists; this can be useful since normally
-#'   PDF images are of higher qualities than raster images like PNG when the
-#'   output is LaTeX/PDF
-#' @param dpi the DPI (dots per inch) value to be used to calculate the output
-#'   width (in inches) of the images from the actual width (in pixels) divided
-#'   by \code{dpi}; if not provided, the chunk option \code{dpi} is used; if
-#'   \code{NA}, the output width will not be calculated
+#' @param path A character vector of image paths.
+#' @param auto_pdf Boolean; whether to use PDF images automatically when the output
+#'   format is LaTeX. If \code{TRUE}, then e.g. \file{foo/bar.png} will be replaced by
+#'   \file{foo/bar.pdf} if the latter exists. This can be useful since normally
+#'   PDF images are of higher quality than raster images like PNG, when the
+#'   output is LaTeX/PDF.
+#' @param dpi DPI (dots per inch) value. Used to calculate the output
+#'   width (in inches) of the images. This will be their actual width in pixels,
+#'   divided by \code{dpi}. If not provided, the chunk option \code{dpi} is used; if
+#'   \code{NA}, the output width will not be calculated.
 #' @note This function is supposed to be used in R code chunks or inline R code
 #'   expressions. You are recommended to use forward slashes (\verb{/}) as path
 #'   separators instead of backslashes in the image paths.
@@ -423,8 +413,8 @@ raster_dpi_width = function(path, dpi) {
 #' the output. \code{include_app()} takes the URL of a Shiny app and adds
 #' \samp{?showcase=0} to it (to disable the showcase mode), then passes the URL
 #' to \code{include_url()}.
-#' @param url a character string of a URL
-#' @param height the height of the iframe
+#' @param url Character string containing a URL.
+#' @param height Character string with the height of the iframe.
 #' @return An R object with a special class that \pkg{knitr} recognizes
 #'   internally to generate the iframe or screenshot.
 #' @seealso \code{\link{include_graphics}}
